@@ -32,9 +32,6 @@ Library for detecting the current OS, including detecting specific
 Linux distributions.
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import codecs
 # to be removed after Ubuntu Xenial is out of support
 import sys
@@ -181,6 +178,7 @@ class Debian(LsbDetect):
                 '12': 'bookworm',
                 '13': 'trixie',
                 '14': 'forky',
+                '15': 'duke',
                 'unstable': 'sid',
                 'rodete': 'trixie',
             }.get(v, '')
@@ -321,6 +319,7 @@ _osx_codename_map = {
  '12': 'monterey',
  '13': 'ventura',
  '14': 'sonoma',
+ '15': 'sequoia',
 }
 
 
